@@ -10,13 +10,13 @@ mod de;
 mod ser;
 mod error;
 
-pub use ser::{to_string, to_events, Serializer};
+pub use ser::{to_string, to_string_custom, to_events, to_events_custom, Serializer};
 pub use de::{from_str, from_string, from_events, Deserializer};
 pub use error::{Error, Result};
 
 lazy_static! {
     static ref NAME_RE: regex::Regex = {
-        regex::Regex::new(r"^(?:\{(?P<n>[^;]+)(?:;(?P<l>.+))?\})?(?:(?P<p>.+):)?(?P<e>.+)$").unwrap()
+        regex::Regex::new(r"^(?:\{(?P<n>[^;]+)(?:;(?P<l>.*))?\})?(?:(?P<p>.+):)?(?P<e>.+)$").unwrap()
     };
 }
 
